@@ -17,8 +17,8 @@ from functools import partial
 import jax
 import jax.numpy as jnp
 
-import pgx
-from pgx.flax.struct import dataclass
+import pgx.core as core
+from pgx._flax.struct import dataclass
 
 TRUE = jnp.bool_(True)
 FALSE = jnp.bool_(False)
@@ -27,7 +27,7 @@ init_dice_pattern: jnp.ndarray = jnp.array([[0, 1], [0, 2], [0, 3], [0, 4], [0,
 
 
 @dataclass
-class State(pgx.State):
+class State(core.State):
     steps: jnp.ndarray = jnp.int32(0)
     current_player: jnp.ndarray = jnp.int8(0)
     observation: jnp.ndarray = jnp.zeros(34, dtype=jnp.int8)
@@ -52,26 +52,21 @@ class State(pgx.State):
     turn: jnp.ndarray = jnp.int8(1)
 
 
-class Backgammon(pgx.Env):
+class Backgammon(core.Env):
     def __init__(
         self,
-        *,
-        auto_reset: bool = False,
-        max_truncation_steps: int = -1,
     ):
-        super().__init__(
-            auto_reset=auto_reset, max_truncation_steps=max_truncation_steps
-        )
+        super().__init__()
 
     def _init(self, key: jax.random.KeyArray) -> State:
         return init(key)
 
-    def _step(self, state: pgx.State, action: jnp.ndarray) -> State:
+    def _step(self, state: core.State, action: jnp.ndarray) -> State:
         assert isinstance(state, State)
         return step(state, action)
 
     def _observe(
-        self, state: pgx.State, player_id: jnp.ndarray
+        self, state: core.State, player_id: jnp.ndarray
     ) -> jnp.ndarray:
         assert isinstance(state, State)
         return observe(state, player_id)
@@ -88,6 +83,10 @@ class Backgammon(pgx.Env):
     def num_players(self) -> int:
         return 2
 
+    @property
+    def _illegal_action_penalty(self) -> float:
+        return -3.0
+
 
 def init(rng: jax.random.KeyArray) -> State:
     rng1, rng2, rng3 = jax.random.split(rng, num=3)
@@ -169,8 +168,10 @@ def _winning_step(
     """
     win_score = _calc_win_score(state.board)
     winner = state.current_player
+    loser = 1 - winner
     reward = jnp.ones_like(state.reward)
     reward = reward.at[winner].set(win_score)
+    reward = reward.at[loser].set(-win_score)
     state = state.replace(terminated=TRUE)  # type: ignore
     return state.replace(reward=reward)  # type: ignore
 
